==> com.liferay.document.library.preview.audio-1.0.5.jar: META-INF/resources/preview/js/AudioPreviewer.es.js <==
"use strict";

Liferay.Loader.define("document-library-preview-audio@1.0.5/preview/js/AudioPreviewer.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-state', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', './AudioPreviewer.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = exports.AudioPreviewer = void 0;

  var _metalState = require("frontend-js-metal-web$metal-state");

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _AudioPreviewer = _interopRequireDefault(require("./AudioPreviewer.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * Component that create an audio player
   * @review
   */
  var AudioPreviewer =
  /*#__PURE__*/
  function (_Component) {
    _inherits(AudioPreviewer, _Component);

    function AudioPreviewer() {
      _classCallCheck(this, AudioPreviewer);

      return _possibleConstructorReturn(this, _getPrototypeOf(AudioPreviewer).apply(this, arguments));
    }

    return AudioPreviewer;
  }(_metalComponent.default);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.AudioPreviewer = AudioPreviewer;
  AudioPreviewer.STATE = {
    /**
     * The max witdh of audio player based in
     * video player width
     * @instance
     * @memberof AudioPreviewer
     * @review
     * @type {!number}
     */
    audioMaxWidth: _metalState.Config.number().required(),

    /**
     * List of of audio sources
     * @instance
     * @memberof AudioPreviewer
     * @review
     * @type {!Array<object>}
     */
    audioSources: _metalState.Config.arrayOf(_metalState.Config.shapeOf({
      type: _metalState.Config.string().required(),
      url: _metalState.Config.string().required()
    })).required()
  };

  _metalSoy.default.register(AudioPreviewer, _AudioPreviewer.default);

  var _default = AudioPreviewer;
  exports.default = _default;
  //# sourceMappingURL=AudioPreviewer.es.js.map
});
//# sourceMappingURL=AudioPreviewer.es.js.map

==> com.liferay.document.library.preview.audio-1.0.20.jar: META-INF/resources/preview/js/AudioPreviewer.es.js <==
Liferay.Loader.define("document-library-preview-audio@1.0.20/preview/js/AudioPreviewer.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', './AudioPreviewer.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.AudioPreviewer = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var _AudioPreviewer = _interopRequireDefault(require("./AudioPreviewer.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * Component that create an audio player
   * @review
   */
  var AudioPreviewer =
  /*#__PURE__*/
  function (_Component) {
    _inherits(AudioPreviewer, _Component);

    function AudioPreviewer() {
      _classCallCheck(this, AudioPreviewer);

      return _possibleConstructorReturn(this, _getPrototypeOf(AudioPreviewer).apply(this, arguments));
    }

    return AudioPreviewer;
  }(_metalComponent["default"]);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.AudioPreviewer = AudioPreviewer;
  AudioPreviewer.STATE = {
    /**
     * The max witdh of audio player based in
     * video player width
     * @instance
     * @memberof AudioPreviewer
     * @review
     * @type {!number}
     */
    audioMaxWidth: _metalState.Config.number().required(),

    /**
     * List of of audio sources
     * @instance
     * @memberof AudioPreviewer
     * @review
     * @type {!Array<object>}
     */
    audioSources: _metalState.Config.arrayOf(_metalState.Config.shapeOf({
      type: _metalState.Config.string().required(),
      url: _metalState.Config.string().required()
    })).required()
  };

  _metalSoy["default"].register(AudioPreviewer, _AudioPreviewer["default"]);

  var _default = AudioPreviewer;
  exports["default"] = _default;
  //# sourceMappingURL=AudioPreviewer.es.js.map
});
//# sourceMappingURL=AudioPreviewer.es.js.map
